Index: channels/chan_dahdi.c
===================================================================
--- channels/chan_dahdi.c	(revision 147052)
+++ channels/chan_dahdi.c	(working copy)
@@ -3638,6 +3638,13 @@
 		break;
 	case AST_OPTION_OPRMODE:  /* Operator services mode */
 		oprmode = (struct oprmode *) data;
+		/* We don't support operator mode across technologies */
+		if (strcasecmp(chan->tech->type, oprmode->peer->tech->type)) {
+			ast_log(LOG_NOTICE, "Operator mode not supported on %s to %s calls.\n",
+					chan->tech->type, oprmode->peer->tech->type);
+			errno = EINVAL;
+			return -1;
+		}
 		pp = oprmode->peer->tech_pvt;
 		p->oprmode = pp->oprmode = 0;
 		/* setup peers */
Index: channels/chan_iax2.c
===================================================================
--- channels/chan_iax2.c	(revision 147052)
+++ channels/chan_iax2.c	(working copy)
@@ -3823,6 +3823,9 @@
 		/* these two cannot be sent, because they require a result */
 		errno = ENOSYS;
 		return -1;
+	case AST_OPTION_OPRMODE:
+		errno = EINVAL;
+		return -1;
 	default:
 		if (!(h = ast_malloc(datalen + sizeof(*h))))
 			return -1;
Index: apps/app_dial.c
===================================================================
--- apps/app_dial.c	(revision 147052)
+++ apps/app_dial.c	(working copy)
@@ -1926,11 +1926,7 @@
 				res = -1;
 				goto done;
 			}
-			if (opermode && !strncmp(chan->tech->type, "DAHDI", 5) && !strncmp(peer->name, "DAHDI", 5)) {
-				/* what's this special handling for dahdi <-> dahdi ?
-				 * A: dahdi to dahdi calls are natively bridged at the kernel driver
-				 * level, so we need to ensure that this mode gets propagated
-				 * all the way down. */
+			if (opermode) {
 				struct oprmode oprmode;
 
 				oprmode.peer = peer;
